spannertools.Hairpin
====================

.. abjad-lineage:: abjad.tools.spannertools.Hairpin.Hairpin

.. autoclass:: abjad.tools.spannertools.Hairpin.Hairpin

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.spannertools.Hairpin.Hairpin.append
      ~abjad.tools.spannertools.Hairpin.Hairpin.append_left
      ~abjad.tools.spannertools.Hairpin.Hairpin.components
      ~abjad.tools.spannertools.Hairpin.Hairpin.detach
      ~abjad.tools.spannertools.Hairpin.Hairpin.direction
      ~abjad.tools.spannertools.Hairpin.Hairpin.extend
      ~abjad.tools.spannertools.Hairpin.Hairpin.extend_left
      ~abjad.tools.spannertools.Hairpin.Hairpin.fracture
      ~abjad.tools.spannertools.Hairpin.Hairpin.fuse
      ~abjad.tools.spannertools.Hairpin.Hairpin.get_duration
      ~abjad.tools.spannertools.Hairpin.Hairpin.get_timespan
      ~abjad.tools.spannertools.Hairpin.Hairpin.include_rests
      ~abjad.tools.spannertools.Hairpin.Hairpin.index
      ~abjad.tools.spannertools.Hairpin.Hairpin.is_hairpin_shape_string
      ~abjad.tools.spannertools.Hairpin.Hairpin.is_hairpin_token
      ~abjad.tools.spannertools.Hairpin.Hairpin.leaves
      ~abjad.tools.spannertools.Hairpin.Hairpin.pop
      ~abjad.tools.spannertools.Hairpin.Hairpin.pop_left
      ~abjad.tools.spannertools.Hairpin.Hairpin.shape_string
      ~abjad.tools.spannertools.Hairpin.Hairpin.start_dynamic_string
      ~abjad.tools.spannertools.Hairpin.Hairpin.stop_dynamic_string
      ~abjad.tools.spannertools.Hairpin.Hairpin.__contains__
      ~abjad.tools.spannertools.Hairpin.Hairpin.__copy__
      ~abjad.tools.spannertools.Hairpin.Hairpin.__eq__
      ~abjad.tools.spannertools.Hairpin.Hairpin.__format__
      ~abjad.tools.spannertools.Hairpin.Hairpin.__getitem__
      ~abjad.tools.spannertools.Hairpin.Hairpin.__len__
      ~abjad.tools.spannertools.Hairpin.Hairpin.__lt__
      ~abjad.tools.spannertools.Hairpin.Hairpin.__ne__
      ~abjad.tools.spannertools.Hairpin.Hairpin.__repr__

Bases
-----

- :py:class:`spannertools.Spanner <abjad.tools.spannertools.Spanner.Spanner>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.spannertools.Hairpin.Hairpin.components
   :noindex:

.. autoattribute:: abjad.tools.spannertools.Hairpin.Hairpin.leaves
   :noindex:

Read/write properties
---------------------

.. autoattribute:: abjad.tools.spannertools.Hairpin.Hairpin.direction
   :noindex:

.. autoattribute:: abjad.tools.spannertools.Hairpin.Hairpin.include_rests
   :noindex:

.. autoattribute:: abjad.tools.spannertools.Hairpin.Hairpin.shape_string
   :noindex:

.. autoattribute:: abjad.tools.spannertools.Hairpin.Hairpin.start_dynamic_string
   :noindex:

.. autoattribute:: abjad.tools.spannertools.Hairpin.Hairpin.stop_dynamic_string
   :noindex:

Methods
-------

.. automethod:: abjad.tools.spannertools.Hairpin.Hairpin.append
   :noindex:

.. automethod:: abjad.tools.spannertools.Hairpin.Hairpin.append_left
   :noindex:

.. automethod:: abjad.tools.spannertools.Hairpin.Hairpin.detach
   :noindex:

.. automethod:: abjad.tools.spannertools.Hairpin.Hairpin.extend
   :noindex:

.. automethod:: abjad.tools.spannertools.Hairpin.Hairpin.extend_left
   :noindex:

.. automethod:: abjad.tools.spannertools.Hairpin.Hairpin.fracture
   :noindex:

.. automethod:: abjad.tools.spannertools.Hairpin.Hairpin.fuse
   :noindex:

.. automethod:: abjad.tools.spannertools.Hairpin.Hairpin.get_duration
   :noindex:

.. automethod:: abjad.tools.spannertools.Hairpin.Hairpin.get_timespan
   :noindex:

.. automethod:: abjad.tools.spannertools.Hairpin.Hairpin.index
   :noindex:

.. automethod:: abjad.tools.spannertools.Hairpin.Hairpin.pop
   :noindex:

.. automethod:: abjad.tools.spannertools.Hairpin.Hairpin.pop_left
   :noindex:

Static methods
--------------

.. automethod:: abjad.tools.spannertools.Hairpin.Hairpin.is_hairpin_shape_string
   :noindex:

.. automethod:: abjad.tools.spannertools.Hairpin.Hairpin.is_hairpin_token
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.spannertools.Hairpin.Hairpin.__contains__
   :noindex:

.. automethod:: abjad.tools.spannertools.Hairpin.Hairpin.__copy__
   :noindex:

.. automethod:: abjad.tools.spannertools.Hairpin.Hairpin.__eq__
   :noindex:

.. automethod:: abjad.tools.spannertools.Hairpin.Hairpin.__format__
   :noindex:

.. automethod:: abjad.tools.spannertools.Hairpin.Hairpin.__getitem__
   :noindex:

.. automethod:: abjad.tools.spannertools.Hairpin.Hairpin.__len__
   :noindex:

.. automethod:: abjad.tools.spannertools.Hairpin.Hairpin.__lt__
   :noindex:

.. automethod:: abjad.tools.spannertools.Hairpin.Hairpin.__ne__
   :noindex:

.. automethod:: abjad.tools.spannertools.Hairpin.Hairpin.__repr__
   :noindex:
